Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(482)

Unified Diff: mojo/public/tools/bindings/generate_type_mappings.py

Issue 2147563004: Mojo C++ bindings: rename "pass_by_value" typemap attribute to "move_only". (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@68_native_types
Patch Set: Created 4 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: mojo/public/tools/bindings/generate_type_mappings.py
diff --git a/mojo/public/tools/bindings/generate_type_mappings.py b/mojo/public/tools/bindings/generate_type_mappings.py
index 77915892967cee1131c1f8a85d8cc038069b7336..e2fbf315c5da4b071adf00865c92883b9fa71222 100755
--- a/mojo/public/tools/bindings/generate_type_mappings.py
+++ b/mojo/public/tools/bindings/generate_type_mappings.py
@@ -97,9 +97,8 @@ def ParseTypemap(typemap):
mojom_type = match_result.group(1)
native_type = match_result.group(2)
- # The only attribute supported currently is "pass_by_value".
- pass_by_value = (match_result.group(3) and
- match_result.group(3) == "pass_by_value")
+ # The only attribute supported currently is "move_only".
+ move_only = match_result.group(3) and match_result.group(3) == "move_only"
assert mojom_type not in result, (
"Cannot map multiple native types (%s, %s) to the same mojom type: %s" %
@@ -107,7 +106,7 @@ def ParseTypemap(typemap):
result[mojom_type] = {
'typename': native_type,
- 'pass_by_value': pass_by_value,
+ 'move_only': move_only,
'public_headers': values['public_headers'],
'traits_headers': values['traits_headers'],
}

Powered by Google App Engine
This is Rietveld 408576698